@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012  Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -265,7 +265,7 @@ LinternaMagica.prototype.player.state = function(id)
     // Add some moving text
     if (time.state)
     {
-	var dots = Math.random()*10;
+	var dots = Math.random()*7;
 	for (var d=0; d <dots ; d ++)
 	{
 	    time.state += ".";
@@ -283,7 +283,7 @@ LinternaMagica.prototype.player.state = function(id)
     time.string = (hour_pos ?
 		   (hour_pos+":") : "")+
 	(min_pos+":")+
-	((sec_pos<10)?"0"+sec_pos:sec_pos) +"/"+
+	((sec_pos<10)?"0"+sec_pos:sec_pos) +" / "+
 	(hour_dur ? (hour_dur+":") : "") +
 	(min_dur+":")+
 	((sec_dur<10)?"0"+sec_dur:sec_dur);
@@ -370,7 +370,10 @@ LinternaMagica.prototype.player.stop = function(id)
     }
     else if (/vlc/i.test(player_name))
     {
-	video_object.playlist.stop();
+	if (video_object.playlist)
+	{
+	    video_object.playlist.stop();
+	}
     }
     else if (/xine/i.test(player_name))
     {
@@ -658,6 +661,7 @@ LinternaMagica.prototype.slider_control = function(event)
 {
     var knob  = null;
     var slider = null;
+    var progress = null;
 
     // find the konb and the slider
     if (event.target.nodeType == 3)
@@ -690,6 +694,9 @@ LinternaMagica.prototype.slider_control = function(event)
 	slider = event.target;
     }
 
+    progress = slider.previousSibling;
+
+
     if (!knob)
     {
 	return null;
@@ -807,9 +814,11 @@ LinternaMagica.prototype.slider_control = function(event)
     }
 
     // Limit position
-    if ((position+knob.clientWidth) >= slider.clientWidth)
+    if ((position+knob.clientWidth) > slider.clientWidth)
     {
-	position = slider.clientWidth - knob.clientWidth;
+	if (direction > 0) {
+	    position = slider.clientWidth - knob.clientWidth;
+	}
     }
 
     if (position < 0)
@@ -821,8 +830,21 @@ LinternaMagica.prototype.slider_control = function(event)
 			   position +"px",
 			   "important");
 
+    progress.style.setProperty("width",
+			   (position ? 
+			    position+3:0) +"px",
+			   "important");
+
+    var percent = (parseInt((
+	position/(slider.clientWidth-knob.clientWidth))*100));
+
+    if (percent > 100)
+    {
+	percent = 100;
+    }
     var return_data = new Object();
-    return_data.val = (parseInt((position/slider.clientWidth) *100))+"%";
+    return_data.val = percent +"%";
+
     return_data.direction = direction;
     return return_data;
 }
@@ -871,7 +893,11 @@ LinternaMagica.prototype.ticker = function(id)
     }
 
 
-    // Move the knob while playing
+    // Move the knob and the progress bar while playing
+    var progress_bar  = document.
+	getElementById("linterna-magica-controls-time-"+
+		       "slider-progress-bar-"+id);
+
     var knob  = document.
 	getElementById("linterna-magica-controls-time-slider-knob-"+id);
 
@@ -893,11 +919,17 @@ LinternaMagica.prototype.ticker = function(id)
 	var pos = parseInt(slider.clientWidth *
 			   time_and_state.percent);
 
-	if (pos >= slider.clientWidth)
-	    pos = slider.clientWidth - knob.clientWidth;;
+	if (pos > (slider.clientWidth-knob.clientWidth))
+	{
+	    pos = slider.clientWidth - knob.clientWidth;
+	}
 
 	knob.style.setProperty(move,
 			       pos+"px",
 			       "important");
+
+	progress_bar.style.setProperty("width",
+				       (pos+3)+"px",
+			       "important");
     }
 }
